@@ -4,16 +4,14 @@ import logging
 import os
 import shutil
 import sys
-import types
 import unittest
 
-from shapely.geometry import asShape, mapping
-
 from fiona import collection
 
-# logging.basicConfig(stream=sys.stderr, level=logging.DEBUG)
+logging.basicConfig(stream=sys.stderr, level=logging.DEBUG)
 
 class ShapefileCollectionTest(unittest.TestCase):
+
     def test_io(self):
         c = collection("docs/data/test_uk.shp", "r")
         self.failUnlessEqual(c.name, "test_uk")
@@ -36,6 +34,11 @@ class ShapefileCollectionTest(unittest.TestCase):
         self.failUnlessEqual(s['CAT'], "float")
         self.failUnlessEqual(s['FIPS_CNTRY'], "str")
 
+    def test_crs(self):
+        c = collection("docs/data/test_uk.shp", "r")
+        self.failUnlessEqual(c.crs['ellps'], 'WGS84')
+        self.failUnless(c.crs['no_defs'])
+
     def test_context(self):
         with collection("docs/data/test_uk.shp", "r") as c:
             self.failUnlessEqual(c.name, "test_uk")
@@ -96,21 +99,23 @@ class ShapefileWriteCollectionTest(unittest.TestCase):
             schema = input.schema.copy()
             schema['geometry'] = 'Point'
             with collection(
-                "test_write_point.shp", "w", "ESRI Shapefile", schema
-                ) as output:
-                    for f in input.filter(bbox=(-5.0, 55.0, 0.0, 60.0)):
-                        f['geometry'] = mapping(asShape(f['geometry']).centroid)
-                        output.write(f)
+                    "test_write_point.shp", "w", "ESRI Shapefile", schema
+                    ) as output:
+                for f in input.filter(bbox=(-5.0, 55.0, 0.0, 60.0)):
+                    f['geometry'] = {
+                        'type': 'Point',
+                        'coordinates': f['geometry']['coordinates'][0][0] }
+                    output.write(f)
 
-    def test_write_polygon(self):
+    def test_write_polygon_with_crs(self):
         with collection("docs/data/test_uk.shp", "r") as input:
             schema = input.schema.copy()
             with collection(
-                "test_write_polygon.shp", "w", "ESRI Shapefile", schema
-                ) as output:
-                    for f in input:
-                        f['geometry'] = mapping(asShape(f['geometry']).buffer(1.0))
-                        output.write(f)
+                    "test_write_polygon.shp", "w", "ESRI Shapefile",
+                    schema=schema, crs={'init': "epsg:4326", 'no_defs': True}
+                    ) as output:
+                for f in input:
+                    output.write(f)
 
 class ShapefileAppendTest(unittest.TestCase):
 
@@ -124,7 +129,9 @@ class ShapefileAppendTest(unittest.TestCase):
                     "w", "ESRI Shapefile", schema
                     ) as output:
                 for f in input.filter(bbox=(-5.0, 55.0, 0.0, 60.0)):
-                    f['geometry'] = mapping(asShape(f['geometry']).centroid)
+                    f['geometry'] = {
+                        'type': 'Point',
+                        'coordinates': f['geometry']['coordinates'][0][0] }
                     output.write(f)
 
     def tearDown(self):
